@@ -437,8 +437,8 @@ app.layout = html.Div(children=[
 """==========================================================================================================
 This block defines how the app responds to all inputs and states
 """
-DATA = {'original': get_data('Costa Rica', 'Seasonally Adjusted')}
-
+#DATA = {'original': get_data('Costa Rica', 'Seasonally Adjusted')}
+DATA = {'original': pd.read_pickle('./data/CRI-initial-data.pickle')}
 
 
 @app.callback(
